@@ -150,5 +150,5 @@ def all_available_arches():
     return all_arches
 
 
-def available_build_names():
-    return ['release', 'debug', 'Release', 'Debug']
+def available_config_names():
+    return ['release', 'debug']
