@@ -13,7 +13,7 @@ import uuid
 from . import common
 from .lib_repo import LibRepo, LibData, LibType
 
-from .common import get_bucket, zip_dir, unzip_file, upload_file, download_file, OSS_BASE_PATH, get_platform_name, available_build_names, available_arches
+from .common import get_bucket, zip_dir, unzip_file, upload_file, download_file, OSS_BASE_PATH, get_platform_name, available_config_names, available_arches
 
 import logging
 logger = logging.getLogger(__name__)
@@ -116,7 +116,7 @@ def parse_args():
     parser = argparse.ArgumentParser(description=description)
     parser.add_argument('--platform', help='Platform', choices=common.available_platforms())
     parser.add_argument('--arch', help='Lib architecture', choices=common.all_available_arches())
-    parser.add_argument('--build', help='Lib build type', choices=common.available_build_names())
+    parser.add_argument('--config', help='Lib config type', choices=common.available_config_names())
     parser.add_argument('--dep', help='The dependencies json file in which the libs will be download from lib repo')
     parser.add_argument('--dest', help='Where download the libs to')
 
@@ -132,7 +132,7 @@ def list_command(args):
     print(str(LibRepo().pull_repo()))
 
 def valid_get_args(args):
-    ordered_args = ['platform', 'arch', 'build']
+    ordered_args = ['platform', 'arch', 'config']
     for index, arg in enumerate(ordered_args):
         if strip(getattr(args, arg)):
             continue
@@ -188,10 +188,10 @@ def lib_get():
                 raise Exception(f'Multiple libs are found for {name} with version {ver}')
         elif potential_libs[0].lib_type in (LibType.BINARY.value,):
             arch = strip(args.arch)
-            build = strip(args.build)
-            found_libs = repo.query_libs(name=name, version=ver, platform=platform, arch=arch, build=build)
+            config = strip(args.config)
+            found_libs = repo.query_libs(name=name, version=ver, platform=platform, arch=arch, config=config)
             if not found_libs:
-                print(f'[error] can not find lib from repo. name: {name}, version: {ver}, platform: {platform}, architecture: {arch}, build: {build}')
+                print(f'[error] can not find lib from repo. name: {name}, version: {ver}, platform: {platform}, architecture: {arch}, config: {config}')
             else:
                 downloading_libs.extend(found_libs)
         else:
@@ -203,9 +203,9 @@ def lib_get():
     libs_dest_dir = strip(args.dest) if strip(args.dest) else os.path.split(dep_config_file)[0]
     libs_dest_dir = os.path.join(libs_dest_dir, platform)
     for lib in downloading_libs:
-        logger.info(f'---------------Begin download library {lib.name}, version: {lib.version}, platform: {lib.platform}, arch: {lib.arch}, config: {lib.build}----------------')
+        logger.info(f'---------------Begin download library {lib.name}, version: {lib.version}, platform: {lib.platform}, arch: {lib.arch}, config: {lib.config}----------------')
         download_lib(lib, libs_dest_dir)
-        logger.info(f'---------------End download library {lib.name}, version: {lib.version}, platform: {lib.platform}, arch: {lib.arch}, config: {lib.build}----------------')
+        logger.info(f'---------------End download library {lib.name}, version: {lib.version}, platform: {lib.platform}, arch: {lib.arch}, config: {lib.config}----------------')
         create_link_to_lib(lib, libs_dest_dir)
     
     logger.info(f'End download dependent 3rd libraries. Cost time: {str(time.time() - start_time)} seconds.')
