@@ -7,7 +7,7 @@ from typing import List, Optional
 from enum import Enum
 from datetime import datetime
 
-from .common import available_arches, available_build_names, available_platforms
+from .common import available_arches, available_config_names, available_platforms
 # import common
 from . import common
 from dacite import from_dict
@@ -27,8 +27,7 @@ class LibData:
     version: Optional[str]
     platform: Optional[str]
     arch: Optional[str]
-    build: Optional[str] # config
-    # build_number: Optional[int]
+    config: Optional[str] # config
     lib_type: Optional[str]
     datetime: Optional[str]
 
@@ -80,7 +79,7 @@ class LibData:
         if self.lib_type != LibType.BINARY.value:
             raise Exception('Not binary lib.')
         
-        return os.path.join(self.name, self.version, 'lib', self.platform, self.arch, self.build)
+        return os.path.join(self.name, self.version, 'lib', self.platform, self.arch, self.config)
     
     def gen_local_path_for_header(self):
         return os.path.join(self.name, self.version, 'include')
@@ -92,14 +91,11 @@ class LibData:
         if self.lib_type != LibType.BINARY.value:
             raise Exception('Not binary lib.')
         
-        return os.path.join(self.name, self.version, 'lib', self.arch, self.build)
+        return os.path.join(self.name, self.version, 'lib', self.arch, self.config)
     
     def is_equal(self, other):
-        '''
-        Not compare build number
-        '''
         return self.name == other.name and self.version == other.version and self.platform == other.platform and \
-            self.arch == other.arch and self.build == other.build and self.lib_type == other.lib_type
+            self.arch == other.arch and self.config == other.config and self.lib_type == other.lib_type
 
     def get_zip_file_name(self):
         return self.name + "_lib.zip"
@@ -111,7 +107,7 @@ class LibData:
         return self.name + '_lib_source.zip'
 
     def __str__(self):
-        return f'{self.name}\t{self.version}\t{self.platform}\t{self.arch}\t{self.build}\t{self.lib_type}\t{self.datetime}'
+        return f'{self.name}\t{self.version}\t{self.platform}\t{self.arch}\t{self.config}\t{self.lib_type}\t{self.datetime}'
 
 
 class LibRepo:
@@ -177,8 +173,14 @@ class LibRepo:
         self.push_repo()
 
         file_keys = [l.file_key() for l in libs if l.lib_type == LibType.BINARY.value]
-        file_keys.extend([l.file_key_for_header() for l in libs])
-        file_keys.extend([l.file_key_for_source() for l in libs])
+        name_versions = set()
+        for l in libs:
+            name_versions.add((l.name, l.version, l.file_key_for_header(), l.file_key_for_source()))
+        for name, version, header_file_key, source_file_key in name_versions:
+            exist = self.find_first(name, version)
+            if not exist:
+                file_keys.extend([header_file_key, source_file_key])
+        
         common.bulk_remove_files(file_keys)
 
     @staticmethod
@@ -211,7 +213,7 @@ class LibRepo:
 
         return None
     
-    def query_libs(self, name: str=None, version: str=None, platform: str=None, arch: str=None, build: str=None) -> list[LibData]:
+    def query_libs(self, name: str=None, version: str=None, platform: str=None, arch: str=None, config: str=None) -> list[LibData]:
         if not self.libs:
             return []
         
@@ -220,7 +222,7 @@ class LibRepo:
             'version': version,
             'platform': platform,
             'arch': arch,
-            'build': build,
+            'config': config,
         }
         results = []
         for lib in self.libs:
@@ -240,19 +242,22 @@ class LibRepo:
 
         return results
 
-    def __str__(self):
-        def sort_key(lib: LibData):
-            return f'{lib.name}-{lib.version}-{lib.platform}-{lib.arch}-{lib.build}-{lib.lib_type}-{lib.datetime}'
-        sorted_libs = sorted(self.libs, key=sort_key)
-
+    @staticmethod
+    def stringify(libs: list[LibData]):
         table_headers = ['Name', 'Version', 'Platform', 'Architecture', 'Build Config', 'Lib Type', 'Time']
         table_rows = []
-        for l in sorted_libs:
-            cells = [l.name, l.version, l.platform, l.arch or '', l.build or '', l.lib_type or '', l.datetime or '']
+        for l in libs:
+            cells = [l.name, l.version, l.platform, l.arch or '', l.config or '', l.lib_type or '', l.datetime or '']
             table_rows.append(cells)
 
         return str(tabulate(table_rows, headers=table_headers))
 
+    def __str__(self):
+        def sort_key(lib: LibData):
+            return f'{lib.name}-{lib.version}-{lib.platform}-{lib.arch}-{lib.config}-{lib.lib_type}-{lib.datetime}'
+        sorted_libs = sorted(self.libs, key=sort_key)
+
+        return LibRepo.stringify(sorted_libs)
 
 def update_lib(local_path: str, header_path: str, source_path: str, lib: LibData):
     def upload_files(dir_path, zip_file_name, file_key):
@@ -293,47 +298,53 @@ def parse_args():
     parser = argparse.ArgumentParser(description=description)
     sub_parsers = parser.add_subparsers(dest='sub_command')
     add_parser = sub_parsers.add_parser('add')
-    add_parser.add_argument('-p', '--path', help='The library folder you want to upload.')
+    add_parser.add_argument('-f', '--binary_folder', help='The library folder you want to upload.')
     add_parser.add_argument('-n', '--name', help='The library name.', required=True)
     add_parser.add_argument('-v', '--version', help='The library version.', required=True)
-    add_parser.add_argument('-s', '--platform', help='Platform the library running.', choices=common.available_platforms())
+    add_parser.add_argument('-p', '--platform', help='Platform the library running.', choices=common.available_platforms())
     add_parser.add_argument('-a', '--arch', help='The library architecture.', choices=common.all_available_arches())
-    add_parser.add_argument('-b', '--build', help='The library build type.', choices=common.available_build_names())
+    add_parser.add_argument('-c', '--config', help='The library config type.', choices=common.available_config_names())
     add_parser.add_argument('--header', help='The header folder.')
     add_parser.add_argument('--source', help='The source code folder.')
 
     remove_parser = sub_parsers.add_parser('remove')
     remove_parser.add_argument('-n', '--name', help='The library name.', required=True)
     remove_parser.add_argument('-v', '--version', help='The library version.')
-    remove_parser.add_argument('-s', '--platform', help='Platform the library running.', choices=common.available_platforms())
+    remove_parser.add_argument('-p', '--platform', help='Platform the library running.', choices=common.available_platforms())
     remove_parser.add_argument('-a', '--arch', help='The library architecture.', choices=common.all_available_arches())
-    remove_parser.add_argument('-b', '--build', help='The library build type.', choices=common.available_build_names())
+    remove_parser.add_argument('-c', '--config', help='The library config type.', choices=common.available_config_names())
 
     return parser.parse_args()
 
 def __validate_header_only_lib_args(args) -> tuple[bool, str]:
-    if args.path or args.platform or args.arch or args.build or args.source:
+    if args.binary_folder or args.platform or args.arch or args.config or args.source:
         return False, 'Too many arguments. Only need -n -v -h for Header-Only library.'
 
     return True, ''
 
 def __validate_source_lib_args(args) -> tuple[bool, str]:
-    if args.path or args.platform or args.arch or args.build:
+    if args.binary_folder or args.platform or args.arch or args.config:
         return False, 'Too many arguments. Only need -n -v --source for source.'
     
     return True, ''
 
 def __validate_binary_lib_args(args) -> tuple[bool, str]:
-    if not args.platform or not args.arch or not args.build or not args.header:
-        return False, 'Too few arguments. Need -s, -a, -b, -h for prebuilt library.'
+    if not args.platform or not args.arch or not args.config:
+        return False, 'Too few arguments. Need -p, -a, -c for prebuilt library.'
+    
+    repo = LibRepo().pull_repo()
+    exist = repo.find_first(args.name, args.version)
+    if exist is None or not common.file_exist(exist.file_key_for_header()):
+        if not args.header:
+            return False, 'Need --header!'
     
     return True, ''
 
 def eval_lib_type(args) -> LibType:
-    if not args.path and not args.header and not args.source:
+    if not args.binary_folder and not args.header and not args.source:
         raise Exception('Must have -p, -h or --source arguments.')
 
-    if args.path:
+    if args.binary_folder:
         return LibType.BINARY
     
     if args.source:
@@ -355,7 +366,6 @@ def validate_args(args) -> tuple[bool, str]:
     
     if lib_type == LibType.HEADER_ONLY:
         return __validate_header_only_lib_args(args)
-    
 
 def __strip_or_none(s):
     if not s:
@@ -366,7 +376,7 @@ def __strip_or_none(s):
 def wait_user_input(message: str, valid_inputs: tuple[str]) -> str:
     options = '/'.join(valid_inputs)
     while True:
-        result = input(f'{message}, input {options}: ')
+        result = input(f'{message}\nInput {options}: ')
         if result not in valid_inputs:
             logger.error(f'Invalid input. You must input {options}')
         else:
@@ -413,7 +423,7 @@ def execute_add(args):
     lib_data = LibData(name=args.name, version=__strip_or_none(args.version),
                        platform=__strip_or_none(args.platform),
                        arch=__strip_or_none(args.arch),
-                       build=__strip_or_none(args.build),
+                       config=__strip_or_none(args.config),
                        lib_type=uploading_lib_type,
                        datetime=str(datetime.now()))
     
@@ -421,7 +431,7 @@ def execute_add(args):
     if exist is None:
         used_header_path = header_path if overwrite_header else None
         used_source_path = source_path if overwrite_source else None
-        update_lib(args.path, used_header_path, used_source_path, lib_data)
+        update_lib(args.binary_folder, used_header_path, used_source_path, lib_data)
     else:
         logger.error(f'The same lib with the version already exist: {str(exist)}')
 
@@ -433,12 +443,20 @@ def execute_remove(args):
     all_libs = []
     for p in platforms:
         libs = lib_repo.query_libs(name=__strip_or_none(args.name), version=__strip_or_none(args.version), platform=p, 
-                                    arch=__strip_or_none(args.arch), build=__strip_or_none(args.build))
+                                    arch=__strip_or_none(args.arch), config=__strip_or_none(args.config))
         if libs:
             all_libs.extend(libs)
 
-    lib_repo.bulk_remove_libs(all_libs)
+    if not all_libs:
+        logger.error("Library not found!")
+        return
 
+    message = LibRepo.stringify(all_libs)
+    confirm = wait_user_yes_no(f'The following libraries will be removed permanently from cloud!\n{message}')
+    if confirm:
+        lib_repo.bulk_remove_libs(all_libs)
+    else:
+        logger.info("Remove operation is cancelled!")
 
 def lib_repo():
     args = parse_args()
